summaryrefslogtreecommitdiff
path: root/src/lib/timer.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-12-19 19:21:50 +0000
committerCarl Hetherington <cth@carlh.net>2013-12-19 19:21:50 +0000
commitf434d010e13ddf834a552be8833abb6f89767fe8 (patch)
treea827edbfac982a93cc7b9641677f0f4c1de6f849 /src/lib/timer.cc
parent8cd68046c5e71ceaed90847aee2ca00c0ccf2e39 (diff)
Fix erroneous rename.
Diffstat (limited to 'src/lib/timer.cc')
-rw-r--r--src/lib/timer.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/lib/timer.cc b/src/lib/timer.cc
index a20a08b07..69a7e3aa9 100644
--- a/src/lib/timer.cc
+++ b/src/lib/timer.cc
@@ -31,14 +31,14 @@
using namespace std;
/** @param n Name to use when giving output */
-PeriodDCPTimer::PeriodDCPTimer (string n)
+PeriodTimer::PeriodTimer (string n)
: _name (n)
{
gettimeofday (&_start, 0);
}
-/** Destroy PeriodDCPTimer and output the time elapsed since its construction */
-PeriodDCPTimer::~PeriodDCPTimer ()
+/** Destroy PeriodTimer and output the time elapsed since its construction */
+PeriodTimer::~PeriodTimer ()
{
struct timeval stop;
gettimeofday (&stop, 0);
@@ -48,7 +48,7 @@ PeriodDCPTimer::~PeriodDCPTimer ()
/** @param n Name to use when giving output.
* @param s Initial state.
*/
-StateDCPTimer::StateDCPTimer (string n, string s)
+StateTimer::StateTimer (string n, string s)
: _name (n)
{
struct timeval t;
@@ -59,7 +59,7 @@ StateDCPTimer::StateDCPTimer (string n, string s)
/** @param s New state that the caller is in */
void
-StateDCPTimer::set_state (string s)
+StateTimer::set_state (string s)
{
double const last = _time;
struct timeval t;
@@ -74,8 +74,8 @@ StateDCPTimer::set_state (string s)
_state = s;
}
-/** Destroy StateDCPTimer and generate a summary of the state timings on cout */
-StateDCPTimer::~StateDCPTimer ()
+/** Destroy StateTimer and generate a summary of the state timings on cout */
+StateTimer::~StateTimer ()
{
if (_state.empty ()) {
return;